@@ -1,7 +1,7 @@
 /*
  * This file is part of nzbget. See <http://nzbget.net>.
  *
- * Copyright (C) 2012-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,10 +56,7 @@ var DownloadsEditDialog = (new function($)
 		$DownloadsEdit_ParamData = $('#DownloadsEdit_ParamData');
 
 		$('#DownloadsEdit_Save').click(saveChanges);
-		$('#DownloadsEdit_Pause').click(itemPause);
-		$('#DownloadsEdit_Resume').click(itemResume);
-		$('#DownloadsEdit_Delete').click(itemDelete);
-		$('#DownloadsEdit_CancelPP').click(itemCancelPP);
+		$('#DownloadsEdit_Actions').click(itemActions);
 		$('#DownloadsEdit_Param, #DownloadsEdit_Log, #DownloadsEdit_File, #DownloadsEdit_Dupe').click(tabClick);
 		$('#DownloadsEdit_Back').click(backClick);
 		$('#DownloadsEdit_Category').change(categoryChange);
@@ -134,12 +131,9 @@ var DownloadsEditDialog = (new function($)
 
 		curGroup = group;
 
-		var status = DownloadsUI.buildStatus(group);
-		var age = Util.formatAge(group.MinPostTime + UISettings.timeZoneCorrection*60*60);
 		var size = Util.formatSizeMB(group.FileSizeMB, group.FileSizeLo);
 		var remaining = Util.formatSizeMB(group.RemainingSizeMB-group.PausedSizeMB, group.RemainingSizeLo-group.PausedSizeLo);
 		var pausedSize = Util.formatSizeMB(group.PausedSizeMB, group.PausedSizeLo);
-		var estimated = group.Status === 'PAUSED' ? '' : (Status.status.DownloadRate > 0 ? Util.formatTimeHMS((group.RemainingSizeMB-group.PausedSizeMB)*1024/(Status.status.DownloadRate/1024)) : '');
 		var completion = group.SuccessArticles + group.FailedArticles > 0 ? Util.round0(group.SuccessArticles * 100.0 / (group.SuccessArticles +  group.FailedArticles)) + '%' : '--';
 		if (group.FailedArticles > 0 && completion === '100%')
 		{
@@ -205,10 +199,6 @@ var DownloadsEditDialog = (new function($)
 		var postParamConfig = ParamTab.createPostParamConfig();
 
 		Util.show('#DownloadsEdit_NZBNameReadonly', group.postprocess);
-		Util.show('#DownloadsEdit_CancelPP', group.postprocess);
-		Util.show('#DownloadsEdit_Delete', !group.postprocess);
-		Util.show('#DownloadsEdit_Pause', group.Kind === 'NZB' && !group.postprocess);
-		Util.show('#DownloadsEdit_Resume', false);
 		Util.show('#DownloadsEdit_Save', !group.postprocess);
 		Util.show('#DownloadsEdit_StatisticsGroup', group.Kind === 'NZB');
 		Util.show('#DownloadsEdit_File', group.Kind === 'NZB');
@@ -236,13 +226,6 @@ var DownloadsEditDialog = (new function($)
 			$('#DownloadsEdit_Category').removeAttr('disabled');
 			$('#DownloadsEdit_Close').removeClass('btn-primary');
 			$('#DownloadsEdit_Close').text('Cancel');
-
-			if (group.RemainingSizeHi == group.PausedSizeHi && group.RemainingSizeLo == group.PausedSizeLo &&
-			    group.Kind === 'NZB')
-			{
-				$('#DownloadsEdit_Resume').show();
-				$('#DownloadsEdit_Pause').hide();
-			}
 		}
 
 		if (postParam)
@@ -250,8 +233,6 @@ var DownloadsEditDialog = (new function($)
 			postParams = ParamTab.buildPostParamTab($DownloadsEdit_ParamData, postParamConfig, curGroup.Parameters);
 		}
 
-		EditUI.buildDNZBLinks(curGroup.Parameters, 'DownloadsEdit_DNZB');
-
 		enableAllButtons();
 
 		$('#DownloadsEdit_GeneralTab').show();
@@ -429,51 +410,21 @@ var DownloadsEditDialog = (new function($)
 			: saveDupeKey();
 	}
 
-	function itemPause(e)
+	function itemActions(e)
 	{
 		e.preventDefault();
-		disableAllButtons();
-		notification = '#Notif_Downloads_Paused';
-		RPC.call('editqueue', ['GroupPause', '', [curGroup.NZBID]], completed);
-	}
+		e.stopPropagation();
+		var elem = $('#DownloadsEdit_Actions').parent();
 
-	function itemResume(e)
-	{
-		e.preventDefault();
-		disableAllButtons();
-		notification = '#Notif_Downloads_Resumed';
-		RPC.call('editqueue', ['GroupResume', '', [curGroup.NZBID]], function()
-		{
-			if (Options.option('ParCheck') === 'force')
+		DownloadsActionsMenu.showPopupMenu(curGroup, 'top',
+			{ left: elem.offset().left, top: elem.offset().top - 1,
+				width: elem.width(), height: elem.height() + 2 },
+			function(_notification)
 			{
-				completed();
-			}
-			else
-			{
-				RPC.call('editqueue', ['GroupPauseExtraPars', '', [curGroup.NZBID]], completed);
-			}
-		});
-	}
-
-	function itemDelete(e)
-	{
-		e.preventDefault();
-		DownloadsUI.deleteConfirm(doItemDelete, false, curGroup.Kind === 'NZB', curGroup.Kind === 'URL');
-	}
-
-	function doItemDelete(command)
-	{
-		disableAllButtons();
-		notification = '#Notif_Downloads_Deleted';
-		RPC.call('editqueue', [command, '', [curGroup.NZBID]], completed);
-	}
-
-	function itemCancelPP(e)
-	{
-		e.preventDefault();
-		disableAllButtons();
-		notification = '#Notif_Downloads_PostCanceled';
-		RPC.call('editqueue', ['PostDelete', '', [curGroup.NZBID]], completed);
+				disableAllButtons();
+				notification = _notification;
+			},
+			completed);
 	}
 
 	function categoryChange()
@@ -857,30 +808,6 @@ var EditUI = (new function($)
 {
 	'use strict'
 
-	this.buildDNZBLinks = function(parameters, prefix)
-	{
-		$('.' + prefix).hide();
-		var hasItems = false;
-
-		for (var i=0; i < parameters.length; i++)
-		{
-			var param = parameters[i];
-			if (param.Name.substr(0, 6) === '*DNZB:')
-			{
-				var linkName = param.Name.substr(6, 100);
-				var $paramLink = $('#' + prefix + '_' + linkName);
-				if($paramLink.length > 0)
-				{
-					$paramLink.attr('href', param.Value);
-					$paramLink.show();
-					hasItems = true;
-				}
-			}
-		}
-
-		Util.show('#' + prefix + '_Section', hasItems);
-	}
-
 	/*** TAB: SERVER STATISTICS **************************************************/
 
 	this.fillServStats = function(table, editItem)
@@ -1062,7 +989,6 @@ var ParamTab = (new function($)
 				var option = section.options[j];
 				if (!option.template && !section.hidden && option.name.substr(option.name.length - 1, 1) === ':')
 				{
-					console.log(option.name);
 					var scriptName = option.name.substr(0, option.name.length-1);
 					if (oldScriptList.indexOf(scriptName) > -1 && newScriptList.indexOf(scriptName) === -1)
 					{
@@ -1539,7 +1465,7 @@ var DownloadsSplitDialog = (new function($)
 
 /*** EDIT HISTORY DIALOG *************************************************************************/
 
-var HistoryEditDialog = (new function()
+var HistoryEditDialog = (new function($)
 {
 	'use strict'
 
@@ -1556,6 +1482,7 @@ var HistoryEditDialog = (new function()
 	var lastFullscreen;
 	var saveCompleted;
 	var logFilled;
+	var showing;
 
 	this.init = function()
 	{
@@ -1563,16 +1490,9 @@ var HistoryEditDialog = (new function()
 		$HistoryEdit_ParamData = $('#HistoryEdit_ParamData');
 
 		$('#HistoryEdit_Save').click(saveChanges);
-		$('#HistoryEdit_Delete').click(itemDelete);
-		$('#HistoryEdit_Return, #HistoryEdit_ReturnURL').click(itemReturn);
-		$('#HistoryEdit_Reprocess').click(itemReprocess);
-		$('#HistoryEdit_Redownload').click(itemRedownload);
-		$('#HistoryEdit_RetryFailed').click(itemRetryFailed);
+		$('#HistoryEdit_Actions').click(itemActions);
 		$('#HistoryEdit_Param, #HistoryEdit_Dupe, #HistoryEdit_Log').click(tabClick);
 		$('#HistoryEdit_Back').click(backClick);
-		$('#HistoryEdit_MarkSuccess').click(itemSuccess);
-		$('#HistoryEdit_MarkGood').click(itemGood);
-		$('#HistoryEdit_MarkBad').click(itemBad);
 
 		LogTab.init('History');
 
@@ -1597,7 +1517,7 @@ var HistoryEditDialog = (new function()
 		TabDialog.extend($HistoryEditDialog);
 	}
 
-	this.showModal = function(hist)
+	this.showModal = function(hist, area)
 	{
 		Refresher.pause();
 
@@ -1697,7 +1617,6 @@ var HistoryEditDialog = (new function()
 			{
 				completion = '99.9%';
 			}
-			var time = Util.formatTimeHMS(hist.DownloadTimeSec + hist.PostTotalTimeSec);
 
 			var table = '';
 			table += '<tr><td><a href="#" id="HistoryEdit_TimeStats" data-tab="HistoryEdit_TimeStatsTab" title="Size and time statistics">Total '+
@@ -1727,18 +1646,10 @@ var HistoryEditDialog = (new function()
 		Util.show($('#HistoryEdit_DupeBackup').closest('.control-group'), hist.Kind === 'NZB');
 		$('#HistoryEdit_DupeMode').closest('.control-group').toggleClass('last-group', hist.Kind !== 'NZB');
 
-		Util.show('#HistoryEdit_Return', hist.RemainingFileCount > 0);
-		Util.show('#HistoryEdit_ReturnURL', hist.Kind === 'URL');
-		Util.show('#HistoryEdit_Redownload', hist.Kind === 'NZB');
-		Util.show('#HistoryEdit_RetryFailed', hist.Kind === 'NZB' && hist.FailedArticles > 0 && hist.RetryData);
-		Util.show('#HistoryEdit_PathGroup, #HistoryEdit_StatisticsGroup, #HistoryEdit_Reprocess', hist.Kind === 'NZB');
+		Util.show('#HistoryEdit_PathGroup, #HistoryEdit_StatisticsGroup', hist.Kind === 'NZB');
 		Util.show('#HistoryEdit_CategoryGroup', hist.Kind !== 'DUP');
 		Util.show('#HistoryEdit_DupGroup', hist.Kind === 'DUP');
 		var dupeCheck = Options.option('DupeCheck') === 'yes';
-		Util.show('#HistoryEdit_MarkSuccess', dupeCheck && ((hist.Kind === 'NZB' && hist.MarkStatus !== 'SUCCESS') || (hist.Kind === 'DUP' && hist.DupStatus !== 'SUCCESS')) &&
-			hist.Status.substr(0, 7) !== 'SUCCESS');
-		Util.show('#HistoryEdit_MarkGood', dupeCheck && ((hist.Kind === 'NZB' && hist.MarkStatus !== 'GOOD') || (hist.Kind === 'DUP' && hist.DupStatus !== 'GOOD')));
-		Util.show('#HistoryEdit_MarkBad', dupeCheck && hist.Kind !== 'URL');
 		Util.show('#HistoryEdit_Dupe', dupeCheck);
 		$('#HistoryEdit_CategoryGroup').toggleClass('control-group-last', hist.Kind === 'URL');
 
@@ -1757,8 +1668,6 @@ var HistoryEditDialog = (new function()
 		var postLog = hist.MessageCount > 0;
 		Util.show('#HistoryEdit_Log', postLog);
 
-		EditUI.buildDNZBLinks(curHist.Parameters ? curHist.Parameters : [], 'HistoryEdit_DNZB');
-
 		enableAllButtons();
 
 		$('#HistoryEdit_GeneralTab').show();
@@ -1776,6 +1685,13 @@ var HistoryEditDialog = (new function()
 		logFilled = false;
 		notification = null;
 
+		if (area === 'backup')
+		{
+			showing = true;
+			$('#HistoryEdit_ServStats').trigger('click');
+		}
+		showing = false;
+
 		$HistoryEditDialog.modal({backdrop: 'static'});
 	}
 
@@ -1842,14 +1758,14 @@ var HistoryEditDialog = (new function()
 	{
 		e.preventDefault();
 
-		$('#HistoryEdit_Back').fadeIn(500);
+		$('#HistoryEdit_Back').fadeIn(showing ? 0 : 500);
 		$('#HistoryEdit_BackSpace').hide();
 		var tab = '#' + $(this).attr('data-tab');
 		lastPage = $(tab);
 		lastFullscreen = ($(this).attr('data-fullscreen') === 'true') && !UISettings.miniTheme;
 
 		$HistoryEditDialog.switchTab($('#HistoryEdit_GeneralTab'), lastPage,
-			e.shiftKey || !UISettings.slideAnimation ? 0 : 500,
+			e.shiftKey || !UISettings.slideAnimation || showing ? 0 : 500,
 			{fullscreen: lastFullscreen, mini: UISettings.miniTheme});
 
 		if (tab === '#HistoryEdit_LogTab' && !logFilled && curHist.MessageCount > 0)
@@ -1887,78 +1803,6 @@ var HistoryEditDialog = (new function()
 		$('#HistoryEdit_Transmit').hide();
 	}
 
-	function itemDelete(e)
-	{
-		e.preventDefault();
-		HistoryUI.deleteConfirm(doItemDelete, curHist.Kind === 'NZB', curHist.Kind === 'DUP',
-			curHist.ParStatus === 'FAILURE' || curHist.UnpackStatus === 'FAILURE' ||
-			curHist.DeleteStatus != 'NONE', false);
-	}
-
-	function doItemDelete(command)
-	{
-		disableAllButtons();
-		notification = '#Notif_History_Deleted';
-		RPC.call('editqueue', [command, '', [curHist.ID]], completed);
-	}
-
-	function itemReturn(e)
-	{
-		e.preventDefault();
-		disableAllButtons();
-		notification = '#Notif_History_Returned';
-		RPC.call('editqueue', ['HistoryReturn', '', [curHist.ID]], completed);
-	}
-
-	function itemRedownload(e)
-	{
-		e.preventDefault();
-		if (curHist.SuccessArticles > 0)
-		{
-			ConfirmDialog.showModal('HistoryEditRedownloadConfirmDialog', doItemRedownload,
-				function () { HistoryUI.confirmMulti(false); });
-		}
-		else
-		{
-			doItemRedownload();
-		}
-	}
-
-	function doItemRedownload()
-	{
-		disableAllButtons();
-		notification = '#Notif_History_Returned';
-		RPC.call('editqueue', ['HistoryRedownload', '', [curHist.ID]], completed);
-	}
-
-	function itemReprocess(e)
-	{
-		e.preventDefault();
-		disableAllButtons();
-		saveCompleted = reprocess;
-		saveDupeKey();
-	}
-
-	function reprocess()
-	{
-		notification = '#Notif_History_Reprocess';
-		RPC.call('editqueue', ['HistoryProcess', '', [curHist.ID]], completed);
-	}
-
-	function itemRetryFailed(e)
-	{
-		e.preventDefault();
-		disableAllButtons();
-		saveCompleted = retryFailed;
-		saveDupeKey();
-	}
-
-	function retryFailed()
-	{
-		notification = '#Notif_History_RetryFailed';
-		RPC.call('editqueue', ['HistoryRetryFailed', '', [curHist.ID]], completed);
-	}
-
 	function completed()
 	{
 		$HistoryEditDialog.modal('hide');
@@ -2003,43 +1847,24 @@ var HistoryEditDialog = (new function()
 			: saveDupeKey();
 	}
 
-	function itemSuccess(e)
+	function itemActions(e)
 	{
 		e.preventDefault();
-		ConfirmDialog.showModal('HistoryEditSuccessConfirmDialog', doItemSuccess, function () { HistoryUI.confirmMulti(false); });
-	}
+		e.stopPropagation();
+		var elem = $('#HistoryEdit_Actions').parent();
 
-	function doItemSuccess()
-	{
-		disableAllButtons();
-		notification = '#Notif_History_Marked';
-		RPC.call('editqueue', ['HistoryMarkSuccess', '', [curHist.ID]], completed);
-	}
-
-	function itemGood(e)
-	{
-		e.preventDefault();
-		ConfirmDialog.showModal('HistoryEditGoodConfirmDialog', doItemGood, function () { HistoryUI.confirmMulti(false); });
-	}
-
-	function doItemGood()
-	{
-		disableAllButtons();
-		notification = '#Notif_History_Marked';
-		RPC.call('editqueue', ['HistoryMarkGood', '', [curHist.ID]], completed);
-	}
-
-	function itemBad(e)
-	{
-		e.preventDefault();
-		ConfirmDialog.showModal('HistoryEditBadConfirmDialog', doItemBad, function () { HistoryUI.confirmMulti(false); });
-	}
-
-	function doItemBad()
-	{
-		disableAllButtons();
-		notification = '#Notif_History_Marked';
-		RPC.call('editqueue', ['HistoryMarkBad', '', [curHist.ID]], completed);
+		HistoryActionsMenu.showPopupMenu(curHist, 'top',
+			{ left: elem.offset().left, top: elem.offset().top - 1,
+				width: elem.width(), height: elem.height() + 2 },
+			function(_notification, actionCallback)
+			{
+				disableAllButtons();
+				notification = _notification;
+				saveCompleted = actionCallback;
+				saveName();
+				return true; // async
+			},
+			completed);
 	}
 
 	/*** TAB: POST-PROCESSING PARAMETERS **************************************************/
